@@ -4,16 +4,15 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_FETCHJOB_H
-#define KIMAP_FETCHJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
 #include "imapset.h"
 #include "job.h"
 
-#include <kmime/kmime_content.h>
-#include <kmime/kmime_message.h>
+#include <KMime/Content>
+#include <KMime/KMimeMessage>
 
 #include <tuple>
 
@@ -475,4 +474,3 @@ private:
 
 }
 
-#endif
