@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_RESPONSE_P_H
-#define KIMAP_RESPONSE_P_H
+#pragma once
 
 #include <QByteArray>
 #include <QList>
@@ -53,7 +52,7 @@ struct Response {
     {
         QByteArray result;
 
-        for (const Part &part : qAsConst(content)) {
+        for (const Part &part : std::as_const(content)) {
             if (part.type() == Part::List) {
                 result += '(';
                 const QList<QByteArray> lstBa = part.toList();
@@ -69,7 +68,7 @@ struct Response {
 
         if (!responseCode.isEmpty()) {
             result += "[ ";
-            for (const Part &part : qAsConst(responseCode)) {
+            for (const Part &part : std::as_const(responseCode)) {
                 if (part.type() == Part::List) {
                     result += '(';
                     const QList<QByteArray> lstBa = part.toList();
@@ -97,4 +96,3 @@ struct Response {
 Q_DECLARE_METATYPE(KIMAP::Response)
 static const int _kimap_messageTypeId = qRegisterMetaType<KIMAP::Response>();
 
-#endif
